==> Xbae-4.7.3.tar.gz: Xbae-4.7.3/include/Xbae/Create.h <==
/*
 * Copyright(c) 1992 Bell Communications Research, Inc. (Bellcore)
 * Copyright(c) 1995-99 Andrew Lister
 *                        All rights reserved
 * Permission to use, copy, modify and distribute this material for
 * any purpose and without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all
 * copies, and that the name of Bellcore not be used in advertising
 * or publicity pertaining to this material without the specific,
 * prior written permission of an authorized representative of
 * Bellcore.
 *
 * BELLCORE MAKES NO REPRESENTATIONS AND EXTENDS NO WARRANTIES, EX-
 * PRESS OR IMPLIED, WITH RESPECT TO THE SOFTWARE, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR ANY PARTICULAR PURPOSE, AND THE WARRANTY AGAINST IN-
 * FRINGEMENT OF PATENTS OR OTHER INTELLECTUAL PROPERTY RIGHTS.  THE
 * SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT SHALL BELLCORE OR
 * ANY OF ITS AFFILIATES BE LIABLE FOR ANY DAMAGES, INCLUDING ANY
 * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
 * ING TO THE SOFTWARE.
 *
 * $Id: Create.h,v 1.5 2000/02/29 19:29:13 danny Exp $
 */

/*
 * Create.h created by Andrew Lister (28 January, 1996)
 */

#ifndef _Xbae_Create_h
#define _Xbae_Create_h
#if defined(__cplusplus) || defined(c_plusplus)
extern "C" {
#endif

#include <Xbae/Macros.h>

void xbaeCopyBackground(Widget, int, XrmValue *);
void xbaeCopyForeground(Widget, int, XrmValue *);
void xbaeCopyDoubleClick(Widget, int, XrmValue *);
void xbaeCopyCellShadowTypes(XbaeMatrixWidget);
void xbaeCopyRowShadowTypes(XbaeMatrixWidget);
void xbaeCopyColumnShadowTypes(XbaeMatrixWidget);
void xbaeCopyCellUserData(XbaeMatrixWidget);
void xbaeCopyRowUserData(XbaeMatrixWidget);
void xbaeCopyColumnUserData(XbaeMatrixWidget);
void xbaeCopySelectedCells(XbaeMatrixWidget);
void xbaeCopyRowLabels(XbaeMatrixWidget);
void xbaeCopyColumnLabels(XbaeMatrixWidget);
void xbaeCopyCells(XbaeMatrixWidget);
void xbaeCopyCellWidgets(XbaeMatrixWidget);
void xbaeCopyColumnWidths(XbaeMatrixWidget);
void xbaeCopyRowHeights(XbaeMatrixWidget);
void xbaeCopyColumnMaxLengths(XbaeMatrixWidget);
void xbaeCopyBackgrounds(XbaeMatrixWidget);
void xbaeCopyColumnAlignments(XbaeMatrixWidget);
void xbaeCopyColumnLabelAlignments(XbaeMatrixWidget);
void xbaeCopyColumnButtonLabels(XbaeMatrixWidget);
void xbaeCopyRowButtonLabels(XbaeMatrixWidget);
void xbaeCopyColors(XbaeMatrixWidget);
#if XmVersion >= 1002
void xbaeCopyHighlightedCells(XbaeMatrixWidget);
#endif
void xbaeCreateDrawGC(XbaeMatrixWidget);
void xbaeCreatePixmapGC(XbaeMatrixWidget);
void xbaeCreateLabelGC(XbaeMatrixWidget);
void xbaeCreateLabelClipGC(XbaeMatrixWidget);
void xbaeCreateGridLineGC(XbaeMatrixWidget);
void xbaeCreateTopShadowClipGC(XbaeMatrixWidget);
void xbaeCreateBottomShadowClipGC(XbaeMatrixWidget);
void xbaeNewFont(XbaeMatrixWidget);
void xbaeNewLabelFont(XbaeMatrixWidget);
void xbaeFreeCells(XbaeMatrixWidget);
void xbaeFreeCellWidgets(XbaeMatrixWidget);
void xbaeFreeRowLabels(XbaeMatrixWidget);
void xbaeFreeColumnLabels(XbaeMatrixWidget);
void xbaeFreeColors(XbaeMatrixWidget);
void xbaeFreeBackgrounds(XbaeMatrixWidget);
void xbaeFreeSelectedCells(XbaeMatrixWidget);
void xbaeFreeCellUserData(XbaeMatrixWidget);
void xbaeFreeCellShadowTypes(XbaeMatrixWidget);
#if XmVersion >= 1002
void xbaeFreeHighlightedCells(XbaeMatrixWidget);
#endif
void xbaeCreateColors(XbaeMatrixWidget);

#if defined(__cplusplus) || defined(c_plusplus)
}
#endif

#endif

==> Xbae-4.50.91.tar.gz: Xbae-4.50.91/include/Xbae/Create.h <==
/*
 * Copyright (c) 1992 Bell Communications Research, Inc. (Bellcore)
 * Copyright (c) 1995-99 Andrew Lister
 * Copyright  1999, 2000, 2001, 2002, 2003 by the LessTif Developers.
 *
 *                        All rights reserved
 * Permission to use, copy, modify and distribute this material for
 * any purpose and without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all
 * copies, and that the name of Bellcore not be used in advertising
 * or publicity pertaining to this material without the specific,
 * prior written permission of an authorized representative of
 * Bellcore.
 *
 * BELLCORE MAKES NO REPRESENTATIONS AND EXTENDS NO WARRANTIES, EX-
 * PRESS OR IMPLIED, WITH RESPECT TO THE SOFTWARE, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR ANY PARTICULAR PURPOSE, AND THE WARRANTY AGAINST IN-
 * FRINGEMENT OF PATENTS OR OTHER INTELLECTUAL PROPERTY RIGHTS.  THE
 * SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT SHALL BELLCORE OR
 * ANY OF ITS AFFILIATES BE LIABLE FOR ANY DAMAGES, INCLUDING ANY
 * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
 * ING TO THE SOFTWARE.
 *
 * $Id: Create.h,v 1.18 2003/10/23 07:25:44 amai Exp $
 */

/*
 * Create.h created by Andrew Lister (28 January, 1996)
 */

#ifndef _Xbae_Create_h
#define _Xbae_Create_h

#include <Xbae/Macros.h>

#ifdef __cplusplus
extern "C" {
#endif

void xbaeCopyBackground(Widget, int, XrmValue *);
void xbaeCopyForeground(Widget, int, XrmValue *);
void xbaeCopyDoubleClick(Widget, int, XrmValue *);
void xbaeCopyCellShadowTypes(XbaeMatrixWidget);
void xbaeCopyRowShadowTypes(XbaeMatrixWidget);
void xbaeCopyColumnShadowTypes(XbaeMatrixWidget);
void xbaeCopyCellUserData(XbaeMatrixWidget);
void xbaeCopyRowUserData(XbaeMatrixWidget);
void xbaeCopyColumnUserData(XbaeMatrixWidget);
void xbaeCopySelectedCells(XbaeMatrixWidget);
void xbaeCopyRowLabels(XbaeMatrixWidget);
void xbaeCopyColumnLabels(XbaeMatrixWidget);
void xbaeCopyCells(XbaeMatrixWidget);
void xbaeCopyCellWidgets(XbaeMatrixWidget);
void xbaeCopyColumnWidths(XbaeMatrixWidget);
void xbaeCopyRowHeights(XbaeMatrixWidget);
void xbaeCopyColumnMaxLengths(XbaeMatrixWidget);
void xbaeCopyBackgrounds(XbaeMatrixWidget);
void xbaeCopyColumnAlignments(XbaeMatrixWidget);
void xbaeCopyColumnLabelAlignments(XbaeMatrixWidget);
void xbaeCopyColumnButtonLabels(XbaeMatrixWidget);
void xbaeCopyColumnShowArrows(XbaeMatrixWidget);
void xbaeCopyColumnFontBold(XbaeMatrixWidget);
void xbaeCopyRowButtonLabels(XbaeMatrixWidget);
void xbaeCopyColors(XbaeMatrixWidget);
void xbaeCopyHighlightedCells(XbaeMatrixWidget);
void xbaeCopyUnderlinedCells(XbaeMatrixWidget);
void xbaeCreateDrawGC(XbaeMatrixWidget);
void xbaeCreatePixmapGC(XbaeMatrixWidget);
void xbaeCreateLabelGC(XbaeMatrixWidget);
void xbaeCreateLabelClipGC(XbaeMatrixWidget);
void xbaeCreateGridLineGC(XbaeMatrixWidget);
void xbaeCreateTopShadowClipGC(XbaeMatrixWidget);
void xbaeCreateBottomShadowClipGC(XbaeMatrixWidget);
void xbaeNewFont(XbaeMatrixWidget, int);
void xbaeNewLabelFont(XbaeMatrixWidget);
void xbaeFreeCells(XbaeMatrixWidget);
void xbaeFreeCellWidgets(XbaeMatrixWidget);
void xbaeFreeRowLabels(XbaeMatrixWidget);
void xbaeFreeColumnLabels(XbaeMatrixWidget);
void xbaeFreeColors(XbaeMatrixWidget);
void xbaeFreeBackgrounds(XbaeMatrixWidget);
void xbaeFreeSelectedCells(XbaeMatrixWidget);
void xbaeFreeCellUserData(XbaeMatrixWidget);
void xbaeFreeCellShadowTypes(XbaeMatrixWidget);
void xbaeFreeHighlightedCells(XbaeMatrixWidget);
void xbaeFreeUnderlinedCells(XbaeMatrixWidget);
void xbaeCreateColors(XbaeMatrixWidget);
void xbaeCopyShowColumnArrows(XbaeMatrixWidget mw);

void xbaeCopyPerCell(XbaeMatrixWidget);
void xbaeFreePerCell(XbaeMatrixWidget);

void xbaeRegisterDisplay(Widget w);
#ifdef __cplusplus
}
#endif

#endif /* _Xbae_Create_h */
